class BaseConfig(object):

    # the ngrok conf for get webhooks
    NGROk_ADDR = 'localhost'
    NGROK_PORT = '80'
    WEBHOOK_SECRET = 'whsec_ockkw25Bge0wgoIkXHhGb6tYZYiNoLzl'
    STRIPE_KEY_TEST = "sk_test_T7ugYRCXZwOezUViefmVlD2E"
